@@ -1,16 +1,21 @@
 # !/usr/bin/env python
 # coding:utf-8
 
-# Copyright (c) 2021. quinn.7@foxmail.com All rights reserved.
+"""
+Copyright (c) 2021. quinn.7@foxmail.com All rights reserved.
+Based on the Apache License 2.0 open source protocol.
 
-# Based on the Apache License 2.0 open source protocol.
+作者 cat7
+邮箱 quinn.7@foxmail.com
 
-__author__ = 'quinn.7@foxmail.com'
+"""
 
 
 def singleton_pattern(cls, *args, **kwargs):
     """
-    单例模式装饰器
+    [ 单例模式装饰器 ]
+    * 无
+
     """
 
     instances = {}
